@@ -14,7 +14,7 @@ function(x, j)
     ## For a matrix x and a vector of column indices j_1, ..., j_n where
     ## n is the number of rows of x, get x[1,j_1], ..., x[n,j_n].
     if(!is.matrix(x))
-        stop(paste("Argument", sQuote("x"), "must be a matrix."))
+        stop("Argument 'x' must be a matrix.")
     x[cbind(seq(length = nrow(x)), j)]
 }
 
@@ -22,7 +22,7 @@ function(x, j)
 function(x, j, value)
 {
     if(!is.matrix(x))
-        stop(paste("Argument", sQuote("x"), "must be a matrix."))
+        stop("Argument 'x' must be a matrix.")        
     x[cbind(seq(length = nrow(x)), j)] <- value
     x
 }
@@ -49,16 +49,23 @@ function(x)
 
 ## Package stats: kmeans() (R 2.1.0 or better).
 n_of_objects.kmeans <- n_of_objects.default
-## Package cclust: cclust().
-n_of_objects.cclust <- n_of_objects.default
-## Package e1071: cmeans(), cshell(), and ufcl() give objects of class
-## "fclust".
-n_of_objects.fclust <-
-function(x)
-    nrow(x$membership)
+
 ## Package cluster: clara(), fanny(), and pam() give objects of the
 ## respective class inheriting from class "partition".
 n_of_objects.partition <- n_of_objects.default
+
+## Package cclust: cclust().
+n_of_objects.cclust <- n_of_objects.default
+
+## Package e1071: cmeans() gives objects of class "fclust".
+n_of_objects.fclust <-
+function(x)
+    nrow(x$membership)
+## Package e1071: cshell().
+n_of_objects.cshell <- n_of_objects.fclust
+## Package e1071: bclust().
+n_of_objects.bclust <- n_of_objects.default
+
 ## Package mclust: Mclust().
 n_of_objects.Mclust <- n_of_objects.default
 
@@ -68,6 +75,7 @@ n_of_objects.Mclust <- n_of_objects.default
 n_of_objects.hclust <-
 function(x)
     length(x$order)
+
 ## Package cluster: agnes() and diana() give objects inheriting from
 ## class "twins".
 n_of_objects.twins <- n_of_objects.hclust
@@ -76,15 +84,15 @@ n_of_objects.mona <- n_of_objects.hclust
 
 ### ** Others.
 
-## Ensembles.
+## Package clue: Ensembles.
 n_of_objects.cl_ensemble <-
 function(x)
     attr(x, "n_of_objects")
-## Memberships.
+## Package clue: Memberships.
 n_of_objects.cl_membership <- nrow
-## cl_pclust.
+## Package clue: cl_pclust().
 n_of_objects.cl_pclust <- n_of_objects.fclust
-## Ultrametrics.
+## Package clue: Ultrametrics.
 n_of_objects.cl_ultrametric <-
 function(x)
     attr(x, "Size")
@@ -111,27 +119,33 @@ function(x)
 
 ## Package stats: kmeans() (R 2.1.0 or better).
 n_of_classes.kmeans <- n_of_classes.default
-## Package cclust: cclust().
-n_of_classes.cclust <- n_of_classes.default
-## Package e1071: cmeans(), cshell(), and ufcl() give objects of class
-## "fclust".
-n_of_classes.fclust <-
-function(x)
-    sum(colSums(x$membership) > 0)
+
 ## Package cluster: clara(), fanny(), and pam() give objects of the
 ## respective class inheriting from class "partition".
-n_of_classes.fanny <- n_of_classes.fclust
+n_of_classes.fanny <-
+function(x)
+    sum(colSums(x$membership) > 0)
 n_of_classes.partition <- n_of_classes.default
+
+## Package cclust: cclust().
+n_of_classes.cclust <- n_of_classes.default
+
+## Package e1071: cmeans() gives objects of class "fclust".
+n_of_classes.fclust <- n_of_classes.fanny
+## Package e1071: cshell().
+n_of_classes.cshell <- n_of_classes.fanny
+## Package e1071: bclust().
+n_of_classes.bclust <- n_of_classes.default
+
 ## Package mclust: Mclust().
 n_of_classes.Mclust <- n_of_classes.default
 
-## Memberships.
+## Package clue: Memberships.
 n_of_classes.cl_membership <-
 function(x)
     attr(x, "n_of_classes")
-    
-## cl_pclust.
-n_of_classes.cl_pclust <- n_of_classes.fclust
+## Package clue: cl_pclust().
+n_of_classes.cl_pclust <- n_of_classes.fanny
 
 ### * cl_class_ids
 
@@ -155,28 +169,35 @@ function(x)
 
 ## Package stats: kmeans() (R 2.1.0 or better).
 cl_class_ids.kmeans <- cl_class_ids.default
-## Package cclust: cclust().
-cl_class_ids.cclust <- cl_class_ids.default
-## Package e1071: cmeans(), cshell(), and ufcl() give objects of class
-## "fclust".
-cl_class_ids.fclust <- cl_class_ids.default
+
 ## Package cluster: clara(), fanny(), and pam() give objects of the
 ## respective class inheriting from class "partition".
 cl_class_ids.partition <-
 function(x)
     x$clustering
+
+## Package cclust: cclust().
+cl_class_ids.cclust <- cl_class_ids.default
+
+## Package e1071: cmeans() gives objects of class "fclust".
+cl_class_ids.fclust <- cl_class_ids.default
+## Package e1071: cshell().
+cl_class_ids.cshell <- cl_class_ids.default
+## Package e1071: bclust().
+cl_class_ids.bclust <- cl_class_ids.default
+
 ## Package mclust: Mclust().
 cl_class_ids.Mclust <-
 function(x)
     x$classification
 
-## Memberships.
+## Package clue: Memberships.
 cl_class_ids.cl_membership <-
 function(x)
     max.col(x)
 ## (Cannot do cl_class_ids.cl_membership <- max.col for generic/method
 ## consistency.)
-## cl_pclust.
+## Package clue: cl_pclust().
 cl_class_ids.cl_pclust <- cl_class_ids.default
 
 ### * is.cl_partition
@@ -203,20 +224,27 @@ function(x)
 
 ## Package stats: kmeans() (R 2.1.0 or better).
 is.cl_partition.kmeans <- .true
-## Package cclust: cclust().
-is.cl_partition.cclust <- .true
-## Package e1071: cmeans(), cshell(), and ufcl() give objects of class
-## "fclust".
-is.cl_partition.fclust <- .true
+
 ## Package cluster: clara(), fanny(), and pam() give objects of the
 ## respective class inheriting from class "partition".
 is.cl_partition.partition <- .true
+
+## Package cclust: cclust().
+is.cl_partition.cclust <- .true
+
+## Package e1071: cmeans() gives objects of class "fclust".
+is.cl_partition.fclust <- .true
+## Package e1071: cshell().
+is.cl_partition.cshell <- .true
+## Package e1071: bclust().
+is.cl_partition.bclust <- .true
+
 ## Package mclust: Mclust().
 is.cl_partition.Mclust <- .true
 
-## Memberships.
+## Package clue: Memberships.
 is.cl_partition.cl_membership <- .true
-## cl_pclust.
+## Package clue: cl_pclust().
 is.cl_partition.cl_pclust <- .true
 
 ### * is.cl_hard_partition
@@ -241,31 +269,38 @@ function(x)
 
 ## Package stats: kmeans() (R 2.1.0 or better).
 is.cl_hard_partition.kmeans <- .true
-## Package cclust: cclust().
-is.cl_hard_partition.cclust <- .true
-## Package e1071: cmeans(), cshell(), and ufcl() give objects of class
-## "fclust".
+
+## Package cluster: clara(), fanny(), and pam() give objects of the
+## respective class inheriting from class "partition".
 ## <NOTE>
 ## Of course, fuzzy clustering can also give a hard partition ...
-is.cl_hard_partition.fclust <-
+is.cl_hard_partition.fanny <-
 function(x)
 {
     all(rowSums(cl_membership(x)) == 1)
 }
 ## </NOTE>
-## Package cluster: clara(), fanny(), and pam() give objects of the
-## respective class inheriting from class "partition".
-is.cl_hard_partition.fanny <- is.cl_hard_partition.fclust
 is.cl_hard_partition.partition <- .true
+
+## Package cclust: cclust().
+is.cl_hard_partition.cclust <- .true
+
+## Package e1071: cmeans() gives objects of class "fclust".
+is.cl_hard_partition.fclust <- is.cl_hard_partition.fanny
+## Package e1071: cshell().
+is.cl_hard_partition.cshell <- is.cl_hard_partition.fanny
+## Package e1071: bclust().
+is.cl_hard_partition.bclust <- .true
+
 ## Package mclust: Mclust().
 is.cl_hard_partition.Mclust <- .true
 
-## Memberships.
+## Package clue: Memberships.
 is.cl_hard_partition.cl_membership <-
 function(x)
     attr(x, "is_cl_hard_partition")
-## cl_pclust.
-is.cl_hard_partition.cl_pclust <- is.cl_hard_partition.fclust
+## Package clue: cl_pclust().
+is.cl_hard_partition.cl_pclust <- is.cl_hard_partition.fanny
 
 ### * as.cl_hard_partition
 
@@ -291,11 +326,15 @@ function(x)
 function(x)
     UseMethod(".maybe_is_proper_soft_partition")
 .maybe_is_proper_soft_partition.default <- .false
-.maybe_is_proper_soft_partition.fclust <- .true
 .maybe_is_proper_soft_partition.fanny <- .true
+.maybe_is_proper_soft_partition.fclust <- .true
+.maybe_is_proper_soft_partition.cshell <- .true
 .maybe_is_proper_soft_partition.cl_membership <-
 function(x)
     !attr(x, "is_cl_hard_partition")
+.maybe_is_proper_soft_partition.cl_pclust <-
+function(x)
+    x$m > 1
 
 ### * is.cl_hierarchy
 
@@ -312,13 +351,14 @@ is.cl_hierarchy.default <- .false
 
 ## Package stats: hclust().
 is.cl_hierarchy.hclust <- .true
+
 ## Package cluster: agnes() and diana() give objects inheriting from
 ## class "twins".
 is.cl_hierarchy.twins <- .true
 ## Package cluster: mona().
 is.cl_hierarchy.mona <- .true
 
-## Ultrametrics.
+## Package clue: Ultrametrics.
 is.cl_hierarchy.cl_ultrametric <- .true
 
 ### Local variables: ***
